#!/bin/bash
#
######################################################################
#
#	install.com.samisit.reseticonservices.launchdaemon.sh
#
#	Samuel Herschbein
#	sam@SamIsIT.com
#	sherschbein@me.com
#
#	Script to install com.samisit.reseticonservices.launchdaemon.
#
#	Details and revision history are in README.txt
#
######################################################################
#
#	Get the script's name.
thisScriptName="${0##*/}"
#	Get the script's path with trailing slash.
thisScriptPath="${0%/*}/"
#
#	Script must be run with sudo.
[[ "$(whoami)" != "root" ]] && { printf "$thisScriptName must be run with sudo.\n\n"; exit; }
#
#	Inform & quit if launch daemon already running (bootstrapped).
launchctlResult="$(sudo launchctl print system | grep 'com.samisit.reseticonservices.launchdaemon' | awk '{print $3}')"
[[ "$launchctlResult" != "" ]] && { printf "\ncom.samisit.reseticonservices.launchdaemon Launch Daemon already running, quitting.\n\n"; exit; }

#
#	Make sure the plist in same directory as this script.
[[ ! -f "$thisScriptPath""com.samisit.reseticonservices.launchdaemon.plist" ]] && { printf "File $thisScriptPath""com.samisit.reseticonservices.launchdaemon.plist not found.\n\n"; exit; }
#
#	Copy the plist.
cp "$thisScriptPath""com.samisit.reseticonservices.launchdaemon.plist" /Library/LaunchDaemons
#	Set ownership & permissions.
chown root:wheel /Library/LaunchDaemons/com.samisit.reseticonservices.launchdaemon.plist
chmod 644 /Library/LaunchDaemons/com.samisit.reseticonservices.launchdaemon.plist
#
#	Bootstrap the LaunchAgent.
launchctlError="$(launchctl bootstrap system /Library/LaunchDaemons/com.samisit.reseticonservices.launchdaemon.plist 2>&1)"
if [[ "$?" -ne 0 ]]; then
	printf "\n%s\n\n" "Error bootstrapping com.samisit.reseticonservices.launchdaemon: ${launchctlError##*: }."
	exit
else
	printf "\n%s\n\n" "com.samisit.reseticonservices.launchdaemon Launch Daemon was bootstrapped successfully."
fi
#
